#!/usr/bin/perl
use lib '/home/erealms/ethereal/mgmt/perl';

################################################################################
# Created       : Martin Foster
# Modified      : 04-Nov-2005
################################################################################
#
# Zoom - Script part of Ethereal Realms, designed to list all zoom in on posts
# Copyright (C) 2000-2007  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 4-3526 Wolfe Cres
#                 Halifax, Nova Scotia
#                 B3L 3S2
#
#################################################################################

use CGI qw(-no_debug -nosticky);				# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Spel;						# Spelling check
use Ethereal::Param;						# Parameter control

#################################################################################
# Gobal override
#################################################################################
$CGI::POST_MAX=1024 * 50;					# Maximum posts
$CGI::DISABLE_UPLOADS = 1;					# Disable uploads

################################################################################
# Data Members
################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $spel;							# Spell check handle
my $param;							# Parameter handle

my $panel;							# Display panel

my $sform;							# Start of form
my $eform;							# End of form
my $psfer;							# Post transfer
my $spell;							# Spell checker button
my $posts;							# Posts textbox

my $post;							# Posting window
my $result;							# Combined results
my $word;							# Current word

my %words;							# Spelling results
my %realm;							# Realm hash


################################################################################
# Program Area
################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new Ethereal::Database();

	# Connect and fetch
	$database->Connect($cgi);

	# Additional instances
	$param    = new Ethereal::Param($database, $cgi);

	# Retreive parameters
	$param->GetParam();

	# Link with hask
	$database->GetHashRealm(\%realm);


	# Definition
	$post = (defined($param->{'POST'})) ? $param->{'POST'} : '';


	# Spell checker
	if (defined($param->{'CHECK'}))
	{
		# Create Spel instance
		$spel = new Ethereal::Spel($database);

		# Check for spelling
		$spel->Check(\%words, $post);

		# Enclosure
		$result = "<TABLE>\n";

		# Loop and generate
		foreach $word (sort(keys(%words)))
		{
			# Generate results
			$result = $result
			   . " <TR>\n"
			   . "  <TD CLASS=\"SPELW\">$word:</TD>\n"		
			   . "  <TD CLASS=\"SPELC\">$words{$word}</TD>\n"
			   . " </TR>";
		}

		# Enclosure
		$result = $result . "</TABLE>\n";
	}
	else
	{
		# Spacing for default
		$result = '&nbsp;';
	}


	# Pull panel
	$panel = $database->FetchRealmZoom($param->{'ROOM'});


	# Generate widgets
	# Form
	$sform = $cgi->start_form(-name=>'ZOOM') . ' ' . $param->EmbedNormal($param->Flat(), CHECK=>'True');	
	$eform = $cgi->end_form();

	# Buttons
	$psfer = $cgi->button(-name=>$realm{'TxtTransfer'}, onClick=>'PushPost(); return false;');
	$spell = $cgi->submit(-name=>$realm{'TxtSpelling'});

	# Textarea
	$posts = $cgi->textarea(-name=>'POST',
		  -default=>$post,
		  -rows=>15,
		  -columns=>75,
		  -wrap=>'SOFT');

	# Replacements
	# Insert Javscript
        if ((!defined($param->{'CHECK'}))
	 && ($panel =~ /<(BODY.*?)>/si))
	{
		# Safety mechanism
		# Assign
		my $org = $1;
		my $new = $1;

		# Prepare
		$new = quotemeta($new);

		# Replace
		$panel =~ s/$new/$org ONLOAD="PullPost()"/gs;
	}

	# Search and replace widgets
	# Macros
	$panel =~ s/MSPELLERS/$result/gs;

	# Widgets
	$panel =~ s/WFORMSTRT/$sform/gs;
	$panel =~ s/WFORMENDS/$eform/gs;
	$panel =~ s/WSUBTXFER/$psfer/gs;
	$panel =~ s/WSUBTSPEL/$spell/gs;
	$panel =~ s/WTEXTPOST/$posts/gs;

	
	# Top of document
	print $cgi->header();
	
	# Display panel
	print $panel, "\n";
